summaryrefslogtreecommitdiffstats
path: root/noatun/library/noatun/app.h
diff options
context:
space:
mode:
Diffstat (limited to 'noatun/library/noatun/app.h')
-rw-r--r--noatun/library/noatun/app.h18
1 files changed, 9 insertions, 9 deletions
diff --git a/noatun/library/noatun/app.h b/noatun/library/noatun/app.h
index c4effa4d..0b8af3ee 100644
--- a/noatun/library/noatun/app.h
+++ b/noatun/library/noatun/app.h
@@ -56,20 +56,20 @@ public:
/**
* @return a list of mimetypes aRts (and thus Noatun) can play
* KFileDialog accepts this QString instead of the shell globs in
* its static functions, make use of it :)
**/
- QString mimeTypes();
+ TQString mimeTypes();
LibraryLoader *libraryLoader() const { return mLibraryLoader; }
Downloader *downloader() const { return mDownloader; }
- static QImage readPNG(const QString &filename);
+ static TQImage readPNG(const TQString &filename);
Effects *effects() const;
::Equalizer *equalizer() const { return mEqualizer; }
::VEqualizer *vequalizer();
KDialogBase *equalizerView() const { return mEqualizerView; }
- QCString version() const;
+ TQCString version() const;
virtual void commitData(QSessionManager &);
virtual void saveState(QSessionManager &);
@@ -121,7 +121,7 @@ public: //options
int startupPlayMode() const;
bool loopList() const;
bool oneInstance() const;
- QString saveDirectory() const;
+ TQString saveDirectory() const;
/**
* @deprecated
* now merged with clearOnOpen()
@@ -138,7 +138,7 @@ public: //options
* software mixing is active
**/
bool fastMixer() const;
- QString titleFormat() const;
+ TQString titleFormat() const;
/**
* @return true if remaining time is displayed to the user, false if
* played time is displayed
@@ -152,7 +152,7 @@ public: //options
*/
void setAutoPlay(bool);
void setStartupPlayMode(int mode);
- void setSaveDirectory(const QString &);
+ void setSaveDirectory(const TQString &);
void setRememberPositions(bool);
/**
* @deprecated
@@ -171,7 +171,7 @@ public: //options
**/
void setFastMixer(bool);
- void setTitleFormat(const QString &);
+ void setTitleFormat(const TQString &);
/**
* Pass true if remaining time should be displayed to the user, false if
@@ -192,7 +192,7 @@ public: //options
*
* @return the ID associated with the menu item, for use in pluginMenuRemove()
**/
- int pluginMenuAdd(const QString &text, const QObject *receiver, const char *member);
+ int pluginMenuAdd(const TQString &text, const TQObject *receiver, const char *member);
/**
* @deprecated
@@ -56,20 +56,20 @@ public:
/**
* @return a list of mimetypes aRts (and thus Noatun) can play
- * KFileDialog accepts this QString instead of the shell globs in
+ * KFileDialog accepts this TQString instead of the shell globs in
* its static functions, make use of it :)
**/